# -*- coding: utf-8 -*-
import scrapy, re
from sanPedroSun.items import NoticiasItem

"""
MEDIO:
The San Pedro Sun, Belice
USO:
scrapy crawl noticias --nolog -s filename=2018-02-23.json -a year=2018 -a month=2 -a day=23
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

# LOC_RE = re.compile(r'\n.+?,? ?.+? ?\. ?- ?')
# G_RE = re.compile(r' ?- ?')
# EM_RE = re.compile(r'((Email|Correo electr.{1,3}nico|Comentarios?):\s)?[\w.-]+@[\w-]+(\.[a-zA-Z]{2,6}){1,2}\s?')
# TW_RE = re.compile(r'M.{1,3}s de la P.{1,3}lvora en Twitter: @[\w.%+-]+.', re.I)
# TW2_RE = re.compile(r'((\| )?Twitter:\s+)?(@[\w.%+-]+.)?', re.I)
# TAG2_RE = re.compile(r'\ntransition_[^\]]+\]')
# TAG3_RE = re.compile(r'\[[^\]]+[\]\n]')


class importantData(scrapy.Item):
    page = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"
    globalSet = set()

    def start_requests(self):
        year = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day = getattr(self, "day", None)

        self.baseURL = "https://www.sanpedrosun.com/wp-content/themes/sunbase/GetResults.php?year=" + year + "&monthnum=" + month + "&day=" + day + "&posts_per_page=8&n_view=standard&n_style=list"
        # self.baseURL = "https://www.sanpedrosun.com/wp-content/themes/sunbase/GetResults.php?year=" + year + "&monthnum=" + month + "&posts_per_page=8&n_view=standard&n_style=list"

        searchData = importantData()
        searchData['page'] = 0

        request = scrapy.Request(url=self.baseURL, callback=self.parse)
        request.meta['item'] = searchData
        yield request


    def parse(self, response):
        localSet = set(response.css('div.entry').xpath('./h2/a/@href').extract())
        resultSet = localSet - self.globalSet

        if len(resultSet) > 0:
            searchData = response.meta['item']

            for link in resultSet:
                self.globalSet.add(link)
                yield scrapy.Request(url=link, callback=self.parse_item)

            searchData['page'] += 1
            page = searchData['page']

            request = scrapy.Request(url=response.url + "&n_more=" + str(page), callback=self.parse)
            request.meta['item'] = searchData
            yield request


    def parse_page(self, response):
        for link in response.css('div.td-ss-main-content').css('div.item-details').xpath('./h3/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        item['title'] = remove_tags(response.xpath('//div[@class="post"]/h1').extract_first()).strip()

        try:
            topic = response.xpath('//div[@class="breadcrumb"]/p/a/text()').extract()[-1]
        except:
            try:
                topic = response.xpath('//ul[@class="td-category"]/li/a/text()').extract_first()
            except:
                topic = None
        item['topic'] = topic

        for p in response.xpath('//div[@class="entry"]').css('p').extract():
            text += remove_tags(p) + "\n"

        # result = LOC_RE.search(text)
        # if result:
        #     m = result.group(0)
        #     location = G_RE.sub('', m).strip()
        #     if len(location) <= 35:
        #         item['location'] = location
        #         text = text[text.find(m)+len(m):]

        # text = EM_RE.sub('', text)
        # text = TW_RE.sub('', text)
        # text = TW2_RE.sub('', text)
        # text = TAG2_RE.sub("\n", text)
        # text = TAG3_RE.sub('', text)
        item['text'] = text.strip()

        item['url'] = response.url

        yield item
